"use strict";
/*
 * Copyright (c) 2022, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.Deauthorizer = void 0;
/**
 * The Deauthorizer is an abstract class that is used to implement a concrete implementation of deauthorizing an environment.
 */
class Deauthorizer {
    async removeAll() {
        const result = {
            successes: [],
            failures: [],
        };
        const environments = await this.find();
        for (const id of Object.keys(environments)) {
            try {
                // avoid configFile collision bug
                // eslint-disable-next-line no-await-in-loop
                await this.remove(id);
                result.successes.push(id);
            }
            catch {
                result.failures.push(id);
            }
        }
        return result;
    }
}
exports.Deauthorizer = Deauthorizer;
//# sourceMappingURL=deauthorizer.js.map