import { Duration } from '@salesforce/kit';
type DurationUnit = Lowercase<keyof typeof Duration.Unit>;
export type DurationFlagConfig = {
    unit: Required<DurationUnit>;
    defaultValue?: number;
    min?: number;
    max?: number;
};
/**
 * Duration flag with built-in default and min/max validation
 * You must specify a unit
 * Defaults to undefined if you don't specify a default
 *
 * @example
 *
 * ```
 * import { Flags } from '@salesforce/sf-plugins-core';
 * public static flags = {
 *    wait: Flags.duration({
 *       min: 1,
 *       unit: 'minutes'
 *       defaultValue: 33,
 *       char: 'w',
 *       description: 'Wait time in minutes'
 *    }),
 * }
 * ```
 */
export declare const durationFlag: import("@oclif/core/lib/interfaces/parser").FlagDefinition<Duration, DurationFlagConfig>;
export {};
//# sourceMappingURL=duration.d.ts.map