export declare const minValidApiVersion = 21;
export declare const maxDeprecated = 30;
export declare const maxDeprecatedUrl = "https://help.salesforce.com/s/articleView?id=000354473&type=1;";
/**
 * apiVersion for a salesforce org's rest api.
 * Will validate format and that the api version is still supported.
 * Will default to the version specified in Config, if it exists (and will provide an override warning)
 *
 * CAVEAT: unlike the apiversion flag on sfdxCommand, this does not set the version on the org/connection
 * We leave this up to the plugins to implement
 *
 * @example
 *
 * ```
 * import { Flags } from '@salesforce/sf-plugins-core';
 * public static flags = {
 *    'api-version': Flags.orgApiVersion({
 *       char: 'a',
 *       description: 'api version for the org'
 *    }),
 * }
 * ```
 */
export declare const orgApiVersionFlag: import("@oclif/core/lib/interfaces/parser").FlagDefinition<string, Record<string, unknown>>;
//# sourceMappingURL=orgApiVersion.d.ts.map